**********************************************************************
**********************************************************************
****CODE ORGANIZING DISPLACED FORMAL WORKERS BY MONTH OF LAYOFF AND MERGING
****THEM TO ALL OBSERVATIONS IN 3 YEARS BEFORE AND 5 YEARS AFTER LAYOFF
****This version: February, 2020

****Input: 
*`year'/`year'_`i'done.dta (multiple files `i' per year `year'; 1994 data came in state-level files so 27 files)
*`year'sample.dta (one file per year `year' of layoff)

****Output: 
*sample`j'.dta (one file per month `j' of layoff)
*sel_sample_all`i'.dta (one file per month `i' of layoff)
**********************************************************************


********************************
**** A) Setup
********************************

clear
set more off
set mem 10000m


********************************
**** B) Organize sample of displaced formal workers by month of layoff
********************************

forvalues year=1995(1)2010 {
forvalues i=1(1)12 {
use "`year'sample.dta", clear
local j=12*(`year'-1995) + `i'
keep if this_sep_month_hat==`j'
bysort id_worker: gen n=_n
keep if n==1
drop n
sort id_worker this_hire_month_hat this_sep_month_hat this_tenure
save "sample`j'.dta", replace
}
}
*192 monthly files from 1 to 192

********************************
**** C) Merge information about all formal jobs in 3 years before and 5 years after layoff
********************************

***prepare empty files to hold the whole history of workers 3 years before and after layoff
clear
gen var1=1
forvalues i=1(1)192 {
save "sel_sample_all`i'.dta", replace
}

***merge history for layoffs taking place in 1995 (only 1 year before, 5 years after)
forvalues j=1(1)12 {

*1994 data
foreach st in "ac" "am" "ap" "ba" "ce" "df" "es" "go" "ma" "mg" "ms" "mt" "pa" "pb" "pe" "pi" "pr" "rj" "rn" "ro" "rr" "rs" "sc" "se" "to" "sp1" "sp2" "sp3" "al"{
use "1994/`st'sample.dta", clear

*create municipality code
rename municipio_code munic
gen muni_code=state*10000+munic
cap drop _merge

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

*1995 data
forvalues year=1995(1)1995 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1996 data
forvalues year=1996(1)1996 {
forvalues i=1(1)12 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 1996 (only 2 years before, 5 years after)
forvalues j=13(1)15 {

*1994 data
foreach st in "ac" "am" "ap" "ba" "ce" "df" "es" "go" "ma" "mg" "ms" "mt" "pa" "pb" "pe" "pi" "pr" "rj" "rn" "ro" "rr" "rs" "sc" "se" "to" "sp1" "sp2" "sp3" "al"{
use "1994/`st'sample.dta", clear

*create municipality code
rename municipio_code munic
gen muni_code=state*10000+munic
cap drop _merge

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

*1995 data
forvalues year=1995(1)1995 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1996 data
forvalues year=1996(1)1996 {
forvalues i=1(1)12 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 1997 (3 years before, 5 years after)
forvalues j=25(1)27 {

*1994 data
foreach st in "ac" "am" "ap" "ba" "ce" "df" "es" "go" "ma" "mg" "ms" "mt" "pa" "pb" "pe" "pi" "pr" "rj" "rn" "ro" "rr" "rs" "sc" "se" "to" "sp1" "sp2" "sp3" "al"{
use "1994/`st'sample.dta", clear

*create municipality code
rename municipio_code munic
gen muni_code=state*10000+munic
cap drop _merge

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

*1995 data
forvalues year=1995(1)1995 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1996 data
forvalues year=1996(1)1996 {
forvalues i=1(1)12 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 1998 (3 years before, 5 years after)
forvalues j=37(1)39 {
*1995 data
forvalues year=1995(1)1995 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1996 data
forvalues year=1996(1)1996 {
forvalues i=1(1)12 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 1999 (3 years before, 5 years after)
forvalues j=49(1)51 {

*1996 data
forvalues year=1996(1)1996 {
forvalues i=1(1)12 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2000 (3 years before, 5 years after)
forvalues j=61(1)63 {

*1997 data
forvalues year=1997(1)1997 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2001 (3 years before, 5 years after)
forvalues j=73(1)75 {

*1998 data
forvalues year=1998(1)1998 {
forvalues i=1(1)11 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2002 (3 years before, 5 years after)
forvalues j=85(1)87 {

*1999 data
forvalues year=1999(1)1999 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2003 (3 years before, 5 years after)
forvalues j=97(1)99 {

*2000 data
forvalues year=2000(1)2000 {
forvalues i=1(1)8 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2004 (3 years before, 5 years after)
forvalues j=109(1)111 {

*2001 data
forvalues year=2001(1)2001 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2005 (3 years before, 5 years after)
forvalues j=121(1)123 {

*2002 data
forvalues year=2002(1)2002 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2006 (3 years before, only 4 years after)
forvalues j=133(1)135 {

*2003 data
forvalues year=2003(1)2003 {
forvalues i=1(1)13 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2007 (3 years before, only 3 years after)
forvalues j=145(1)147 {

*2004 data
forvalues year=2004(1)2004 {
forvalues i=1(1)14 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2008 (3 years before, only 2 years after)
forvalues j=157(1)159 {

*2005 data
forvalues year=2005(1)2005 {
forvalues i=1(1)15 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


***merge history for layoffs taking place in 2009 (3 years before, only 1 year after)
forvalues j=169(1)171 {

*2006 data
forvalues year=2006(1)2006 {
forvalues i=1(1)19 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}

 
***merge history for layoffs taking place in 2010 (3 years before, 0 years after)
forvalues j=181(1)183 {

*2007 data
forvalues year=2007(1)2007 {
forvalues i=1(1)20 {
use "`year'/`year'_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2008 data
forvalues year=2008(1)2008 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2009 data
forvalues year=2009(1)2009 {
forvalues i=1(1)4 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)4 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}

*2010 data
forvalues year=2010(1)2010 {
forvalues i=1(1)5 {
use "`year'/`year'a_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'b_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}

forvalues i=1(1)5 {
use "`year'/`year'c_`i'done.dta", clear

*create municipality code
gen muni_code=state*10000+munic

*rearrange separation month and hiring month variables within a year
replace sep_month=99 if reas_sep==0
gen hir_month=hire_month
replace hir_month=0 if hire_type==8

*create continuous hiring month and separation month variables
gen hire_month_hat = 0
replace hire_month_hat = 12*(year-1995) + hir_month if hir_month~=0
gen sep_month_hat = 0
replace sep_month_hat = 12*(year-1995) + sep_month if sep_month~=99

*merge to layoff sample
sort id_worker
merge id_worker using "sample`j'.dta", nokeep
keep if this_sep_month_hat==`j'
sort id_worker
append using "sel_sample_all`j'.dta"
save "sel_sample_all`j'.dta", replace
}
}
}


